jj.kuoka.acl


current-user-privilegesclj

(current-user-privileges resource-path auth-user state)

Compute the set of non-abstract privileges the current user has on a resource.

Compute the set of non-abstract privileges the current user has on a resource.
sourceraw docstring

default-aclclj

(default-acl owner-href)

Create a default ACL for a new resource owned by owner-href.

Create a default ACL for a new resource owned by owner-href.
sourceraw docstring

default-acl-restrictionsclj

source

evaluate-aclclj

(evaluate-acl acl required-privs auth-user resource-path state)

Evaluate an ACL for a given request. Returns true if access is granted.

Per RFC 3744 Section 6: ACEs are evaluated in order. A matching deny ACE for an ungranted required privilege causes immediate denial. Grant ACEs accumulate. When all required privileges are granted, access is allowed.

Evaluate an ACL for a given request. Returns true if access is granted.

Per RFC 3744 Section 6: ACEs are evaluated in order. A matching deny ACE
for an ungranted required privilege causes immediate denial. Grant ACEs
accumulate. When all required privileges are granted, access is allowed.
sourceraw docstring

home-aclclj

(home-acl owner-href admin-href)

Create an ACL for a user's home directory. Only the user and admin have access.

Create an ACL for a user's home directory. Only the user and admin have access.
sourceraw docstring

method-requires-privileges?clj

(method-requires-privileges? method)
source

required-privileges-for-methodclj

(required-privileges-for-method method exists?)

Return the set of privileges required to execute a method on a resource. exists? is whether the resource currently exists.

Return the set of privileges required to execute a method on a resource.
`exists?` is whether the resource currently exists.
sourceraw docstring

supported-privilegesclj

(supported-privileges)

Return the full privilege tree info as a seq of maps for XML generation.

Return the full privilege tree info as a seq of maps for XML generation.
sourceraw docstring

validate-ace-privilegesclj

(validate-ace-privileges privs)

Validate that an ACE's privileges are all non-abstract and known.

Validate that an ACE's privileges are all non-abstract and known.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries