jj.kuoka.handler


add-userclj

(add-user st
          username
          password
          &
          {:keys [displayname] :or {displayname username}})

Add a principal with password to the given state atom. Creates a home directory at /<username>/ with an isolated ACL. Returns the principal-url.

Add a principal with password to the given state atom.
Creates a home directory at /<username>/ with an isolated ACL.
Returns the principal-url.
sourceraw docstring

init-stateclj

(init-state webdav-root & {:keys [admin-password]})

Return a fresh state atom with root ACL and webdav-root. Requires :admin-password to create the admin principal. Each user gets a home directory at /<username>/.

Return a fresh state atom with root ACL and webdav-root.
Requires :admin-password to create the admin principal.
Each user gets a home directory at /<username>/.
sourceraw docstring

make-appclj

(make-app state)

Create the full Ring handler stack, injecting the given state atom. The state atom must contain :webdav-root (set by init-state).

Create the full Ring handler stack, injecting the given state atom.
The state atom must contain :webdav-root (set by init-state).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries