jj.kuoka.xml


child-elementclj

(child-element local)
(child-element local attrs)
(child-element local attrs & content)
source

dav-nsclj

source

dav-prefixclj

source

elementclj

(element local content)
(element local attrs & content)
source

emit-xmlclj

(emit-xml el)
source

error-bodyclj

(error-body resources-needed)
source

lock-entry-xmlclj

(lock-entry-xml lock)
source

multi-status-bodyclj

(multi-status-body responses)
source

parse-acl-bodyclj

(parse-acl-body body-el)

Parse an ACL method request body into a list of ACE data structures.

Parse an ACL method request body into a list of ACE data structures.
sourceraw docstring

parse-propfindclj

(parse-propfind body-el)

Extract requested property names from a parsed PROPFIND body. Returns :allprop, :propname, or a seq of property keywords like [:dav/displayname].

Extract requested property names from a parsed PROPFIND body.
Returns :allprop, :propname, or a seq of property keywords like [:dav/displayname].
sourceraw docstring

parse-proppatchclj

(parse-proppatch body-el)

Parse a PROPPATCH request body. Returns {:set {prop-key val ...} :remove [prop-key ...]}

Parse a PROPPATCH request body. Returns {:set {prop-key val ...} :remove [prop-key ...]}
sourceraw docstring

parse-report-bodyclj

(parse-report-body body-el)

Parse a REPORT request body. Returns {:type ...} map.

Parse a REPORT request body. Returns {:type ...} map.
sourceraw docstring

parse-xml-bodyclj

(parse-xml-body request)

Parse XML from a Ring request. Extracts :body and parses with clojure.data.xml.

Parse XML from a Ring request. Extracts :body and parses with clojure.data.xml.
sourceraw docstring

property-xmlclj

(property-xml prop-key prop-val)
source

status-elclj

(status-el msg)
source

text-elclj

(text-el local text)
source

cljdoc builds & hosts documentation for Clojure/Script libraries