(child-element local)(child-element local attrs)(child-element local attrs & content)(parse-acl-body body-el)Parse an ACL method request body into a list of ACE data structures.
Parse an ACL method request body into a list of ACE data structures.
(parse-propfind body-el)Extract requested property names from a parsed PROPFIND body. Returns :allprop, :propname, or a seq of property keywords like [:dav/displayname].
Extract requested property names from a parsed PROPFIND body. Returns :allprop, :propname, or a seq of property keywords like [:dav/displayname].
(parse-proppatch body-el)Parse a PROPPATCH request body. Returns {:set {prop-key val ...} :remove [prop-key ...]}
Parse a PROPPATCH request body. Returns {:set {prop-key val ...} :remove [prop-key ...]}
(parse-report-body body-el)Parse a REPORT request body. Returns {:type ...} map.
Parse a REPORT request body. Returns {:type ...} map.
(parse-xml-body request)Parse XML from a Ring request. Extracts :body and parses with clojure.data.xml.
Parse XML from a Ring request. Extracts :body and parses with clojure.data.xml.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |